Notes, summaries, assignments, exams, and problems for Other courses

Essential Calculus and Probability Formulas

Other languages7.39 KB

Probability Concepts

  • Union of Events: P(A∪B) = P(A) + P(B) - P(A∩B)
  • Complement of an Event: P(Ac) = 1 - P(A)
  • Intersection of B and Complement of A: P(B∩Ac) = P(B) - P(A∩B)
  • Conditional Probability: P(B|A) = P(A∩B) / P(A)
  • Intersection of Complements: P(Ac∩Bc) = 1 - P(A∪B)
  • Mutually Exclusive Events: P(A∩B) = 0
  • Independent Events: P(A∩B) = P(A)·P(B)

Binomial Distribution Parameters

  • Mean (μ): μ = n·p
  • Standard Deviation (σ): σ = √(n·p·q)

Binomial Distribution

Notation: B(n, p)

Probability Mass Function: P(X=a) = (na) pa qn-a

Where:

  • n = number of trials
  • p = probability of success
  • q = complement of p (q = 1-p)

Normal Distribution

Notation: X ∼ N(μ, σ)

Important Probabilities:

  • P(Z < a) or P(Z > a) can be found using a standard normal
...
Continue reading "Essential Calculus and Probability Formulas" »

Complex Analysis: Continuity, Differentiability, and Limits

Mathematics679.84 KB

Functions and Objectives

(a) f(z) = |z|, where z is a complex number.

(b) f(x, y) = x²y / (x² + y²)

Proof Objective

  • (a) Prove that f(z) = |z| is continuous everywhere but nowhere differentiable except at the origin.
  • (b) Find the iterative limit and simultaneous limit of f(x, y) = x²y / (x² + y²) as (x, y) → (0, 0).

Proof Process

(a) Continuity of f(z) = |z|

[Step 1]: Show that f(z) = |z| is continuous everywhere.

Let z₀ be an arbitrary complex number. We want to show that for any ε > 0, there exists a δ > 0 such that if |z - z₀| < δ, then |f(z) - f(z₀)| < ε.

We have f(z) = |z| and f(z₀) = |z₀|. Then |f(z) - f(z₀)| = ||z| - |z₀||.

By the reverse triangle inequality, we know that ||z| - |z₀|| ≤ |z - z₀|.

So, if...

Continue reading "Complex Analysis: Continuity, Differentiability, and Limits" »

Internet Fundamentals: Protocols, Web Browsers, and Network Architecture

Computers7.49 KB

Internet vs. World Wide Web (WWW)

  • Internet: A global network infrastructure that uses TCP/IP to connect devices worldwide.
  • WWW (World Wide Web): A multimedia service built upon the Internet, utilizing HTML, CSS, web browsers, and hyperlinks.
  • Webpage: A single document accessible via the WWW. | Website: A collection or group of related webpages.

History and Evolution of the Internet

  • 1960s: Development of ARPANET (Advanced Research Projects Agency Network).
  • 1983: Adoption of the TCP/IP protocol suite (developed by Vint Cerf and Bob Kahn).
  • 1989: Invention of the World Wide Web (WWW) by Tim Berners-Lee.
  • 1992: Release of the Mosaic browser (developed at UIUC), popularizing the graphical web.

Understanding the Client-Server Model

  • Client: Initiates a request
...
Continue reading "Internet Fundamentals: Protocols, Web Browsers, and Network Architecture" »

Network Fundamentals: Protocols, Addressing, Security

Computers17.78 KB

TCP Reliable Transfer and Connection Management

TCP Reliable Transfer

  1. Sequence Numbers

    • Each byte of data is assigned a sequence number. This number is used by the receiver to correctly order the data and ensure there are no missing segments.
  2. Acknowledgements

    • The receiver sends back an ACK to the sender for the sequence number of the next expected byte. If the sender receives the ACK before its timer expires, it knows everything up to that byte was received correctly.
  3. Retransmission

    • If the ACK is not received before the timer expires, the sender retransmits the data.

TCP Connection Management

Managing a TCP connection begins with a three-way handshake, which establishes a connection before any actual data is transmitted.

Steps in Three-Way Handshake

  1. SYN
    • The
...
Continue reading "Network Fundamentals: Protocols, Addressing, Security" »

Core Theories of Language Acquisition: UG, Krashen, and SLA Concepts

Electronics7.29 KB

The Logical Problem of Language Acquisition

The logical problem of language acquisition refers to how children learn complex grammar despite limited and often imperfect input. Universal Grammar (UG) addresses this by proposing an innate set of grammatical principles that inherently guide language learning, suggesting that children are born with a blueprint for language structure.

The Wug Test and Rule-Based Learning

The Wug Test is a classic experiment designed to assess children's morphological knowledge. The findings show that children can apply grammatical rules (like pluralization or past tense) to novel, made-up words (e.g., 'wug' becomes 'wugs'). This indicates that language learning is a rule-based, creative process, not just imitation....

Continue reading "Core Theories of Language Acquisition: UG, Krashen, and SLA Concepts" »

Cost Classification, Costing Methods, and Break-Even Analysis

Mathematics3.83 KB

Cost Classification and Analysis for Business Success

Understanding Cost Classifications

Costs can be classified in several ways, providing different insights for business decision-making:

  • Function: Such as the department incurring the cost (e.g., production, administration).
  • Type: Categorized as Direct or Indirect costs.
  • Behavior: How costs react to changes in output, including Fixed, Variable, and Semi-Variable costs.
  • Time: Costs associated with a specific period (e.g., period costs).

Direct Costs (Prime Costs)

Direct Costs are expenses that can be easily and directly related to the production of a specific item or service. They are also known as prime costs. For example, the salaries of employees working directly in a production department or the...

Continue reading "Cost Classification, Costing Methods, and Break-Even Analysis" »

Montbarry Mystery: Key Plot Points and Character Insights

English2.72 KB

Key Plot Developments in the Montbarry Mystery

  • Henry agreed with the other club members that Montbarry’s death seemed suspicious.
  • Mr. Troy was unable to persuade Emily that Countess Narona had no ill intentions.
  • Due to a deception, Dr. Bruno was led to believe that Montbarry’s death had been natural.
  • The Countess returned to Venice after she started suffering from visions and paranoia.
  • The only person who trusted Agnes’ story about the severed head was Dr. Bruno.

Critical Questions and Answers on the Montbarry Case

Countess's Safety in Venice from Agnes

The Countess assumed that Agnes would never come to Venice because of everything that had happened related to Montbarry’s death.

Dr. Bruno's Certainty About Montbarry

Dr. Bruno was sure because...

Continue reading "Montbarry Mystery: Key Plot Points and Character Insights" »

Future Tenses and Conditionals: Structure and Usage

English3.13 KB

Mastering Advanced Future Tenses

Future Continuous Tense

We use the Future Continuous to talk about an action that will be in progress at a certain time in the future.

Example: This time tomorrow, I'll be flying to Greece.

Structure:

Subject + will be + -ing form

Future Perfect Simple Tense

We use the Future Perfect Simple to talk about an action completed before a certain time in the future.

Example: By 3 p.m. tomorrow, I'll have arrived in Greece.

Structure:

Subject + will have + past participle

Future Perfect Continuous Tense

We use the Future Perfect Continuous to say how long an action will have been in progress at a certain time in the future.

Example: By next Saturday, I'll have been travelling around Greece for a week.

Structure:

Subject + will have

...
Continue reading "Future Tenses and Conditionals: Structure and Usage" »

Distillation Equipment Selection and Column Design

Technology2.58 KB

Criteria for Selecting Distillation Equipment

  • Pressure Drop: Packed towers have a lower pressure drop (1/5th to 1/8th of tray towers), making them suitable for high vacuum distillation.
  • Tower Diameter: Packed towers are preferred for very small diameters (<150 mm) due to fabrication difficulties with trays, while tray towers are used for large diameters to ensure proper liquid distribution.
  • Liquid-Vapor Ratio: Packed towers are suitable for high L/V ratios, while tray towers are better for very low L/V ratios due to minimum wetting rate requirements.
  • Corrosive Systems: Packed towers with plastic or reinforced plastic packings are more economical than tray towers requiring special metal alloys (e.g., Hastelloy-B for methyl iodide-acetic acid
...
Continue reading "Distillation Equipment Selection and Column Design" »

CUDA Matrix Multiplication: Shared Memory

Computers3.23 KB

CUDA Matrix Multiplication Using Shared Memory

This code demonstrates matrix multiplication in CUDA, leveraging shared memory for optimization. It includes two examples: a kernel using shared memory and a host-side implementation using the Thrust library.

CUDA Kernel with Shared Memory

The following CUDA kernel performs matrix multiplication using shared memory to optimize data access:


__global__ void matMulShared(int *A, int *B, int *C, int rowsA, int colsA, int colsB) {
    __shared__ int tile_A[TILE_SIZE][TILE_SIZE], tile_B[TILE_SIZE][TILE_SIZE];
    int row = blockIdx.y * TILE_SIZE + threadIdx.y, col = blockIdx.x * TILE_SIZE + threadIdx.x, temp = 0;
    for (int i = 0; i < (colsA + TILE_SIZE - 1) / TILE_SIZE; ++i) {
        if (row <
...
Continue reading "CUDA Matrix Multiplication: Shared Memory" »